@@ -16,7 +16,8 @@ const AccountsMonitor = new Lang.Class({
     Name: 'AccountsMonitor',
 
     _init: function() {
-        this._accounts = [];
+        this._accounts = new Map();
+        this._accountSettings = new Map();
 
         this._app = Gio.Application.get_default();
         this._app.connect('prepare-shutdown',
@@ -29,18 +30,48 @@ const AccountsMonitor = new Lang.Class({
         factory.add_channel_features([Tp.Channel.get_feature_quark_contacts()]);
         factory.add_contact_features([Tp.ContactFeature.ALIAS]);
 
+        this._preparedCallbacks = [];
         this._accountManager.prepare_async(null,
                                            Lang.bind(this, this._onPrepared));
     },
 
-    dupAccounts: function() {
-        return this._accounts.slice();
+    get accounts() {
+        return [...this._accounts.values()];
+    },
+
+    get enabledAccounts() {
+        return [...this._accounts.values()].filter(a => a.enabled);
     },
 
     get accountManager() {
         return this._accountManager;
     },
 
+    lookupAccount: function(accountPath) {
+        return this._accounts.get(accountPath);
+    },
+
+    getAccountSettings: function(account) {
+        let accountPath = account.object_path;
+        let settings = this._accountSettings.get(accountPath);
+        if (settings)
+            return settings;
+
+        let path = '/org/gnome/Polari/Accounts/%s/'.format(account.get_path_suffix());
+        settings = new Gio.Settings({ schema_id: 'org.gnome.Polari.Account',
+                                      path: path });
+        this._accountSettings.set(accountPath, settings);
+        return settings;
+    },
+
+    prepare: function(callback) {
+        let quark = Tp.AccountManager.get_feature_quark_core();
+        if (this._accountManager.is_prepared(quark))
+            callback();
+        else
+            this._preparedCallbacks.push(callback);
+    },
+
     _onPrepared: function(am, res) {
         try {
             am.prepare_finish(res);
@@ -67,26 +98,20 @@ const AccountsMonitor = new Lang.Class({
         am.connect('account-disabled',
                    Lang.bind(this, this._accountEnabledChanged));
 
-        this.emit('account-manager-prepared', am);
+        this._preparedCallbacks.forEach(callback => { callback(); });
     },
 
     _onPrepareShutdown: function() {
-        for (let i = 0; i < this._accounts.length; i++) {
-            let account = this._accounts[i];
-
-            let presence = Tp.ConnectionPresenceType.OFFLINE;
-            if (account.requested_presence_type == presence)
-                continue;
-
+        let presence = Tp.ConnectionPresenceType.OFFLINE;
+        this.accounts.filter(a => a.requested_presence != presence).forEach(a => {
             this._app.hold();
-            account.request_presence_async(presence, 'offline', '',
-                Lang.bind(this, function(account, result) {
-                    try {
-                        account.request_presence_finish(result);
-                    } catch(e) { }
-                    this._app.release();
-                }));
-        }
+            a.request_presence_async(presence, 'offline', '', (a, res) => {
+                try {
+                    a.request_presence_finish(result);
+                } catch(e) { }
+                this._app.release();
+            });
+        });
     },
 
     _shouldMonitorAccount: function(account) {
@@ -97,34 +122,36 @@ const AccountsMonitor = new Lang.Class({
         if (!this._shouldMonitorAccount(account))
             return;
 
+        if (this._accounts.has(account.object_path))
+            return;
+
         account._statusNotifyId =
             account.connect('notify::connection-status', Lang.bind(this,
                 function() {
                     this.emit('account-status-changed', account);
                 }));
-        this._accounts.push(account);
+        this._accounts.set(account.object_path, account);
 
         this.emit('account-added', account);
         this.emit('accounts-changed');
     },
 
     _removeAccount: function(account) {
-        let index = this._accounts.indexOf(account);
-
-        if (index == -1)
+        if (!this._accounts.delete(account.object_path))
             return;
 
         account.disconnect(account._statusNotifyId);
         delete account._statusNotifyId;
-        this._accounts.splice(index, 1);
 
         this.emit('account-removed', account);
         this.emit('accounts-changed');
     },
 
     _accountEnabledChanged: function(am, account) {
-        if (this._accounts.indexOf(account) == -1)
+        if (!this._accounts.has(account.object_path))
             return;
+        this.emit(account.enabled ? 'account-enabled'
+                                  : 'account-disabled', account);
         this.emit('accounts-changed');
     }
 });
